# 词向量

## Word2Vec
- [skip-gram][1]: 1个学生(中心词) `汇报 =>` K个老师(周围词)
- cbow: K个学生(周围词) `汇报 =>` 1个老师(中心词)


---
[1]: https://www.cnblogs.com/june0507/p/9412989.html




# 翻译
https://www.cnblogs.com/fanyang1/p/9414088.html
